/** \file main.c
 *
 * \brief GPIO: LEDs.
 *
 * This example program switches LEDs on and off.
 *
 * The relevant registers are:
 * - DIR: Data Direction Register
 * - OUT: Data Output Value
 *
 * Please see modules 4.2.1 and 4.3.3 for more information.
 * 
 * \author    Wolfgang Neff
 * \version   1.4
 * \date      2018-06-27
 *
 * \par History
 *      Created: 2013-07-16 \n
 *      Modified: 2014-09-28 \n
 *      Modified: 2014-10-12 \n
 *      Modified: 2014-10-17 \n
 *      Modified: 2018-06-27
 */

// Include the modules used by this program.
#include <avr/io.h>
#include <util/delay.h>

#include "board.h"

// At first we want to have the following initial state: LED0: on, LED1: off, LED2: off, LED3: on.
// Then we want that LED1 and LED2 are blinking. The definitions for the microcontroller come from
// module avr/io.h. The definition for the delay routine comes from util/delay and the definitions
// for the microcontroller board come from board.h. avr/io.h and util/delay are system modules.
// board.h is a user module.
/***** This is the main program. *****/
int main(void)
{
	/***** Initialize Hardware *****/
	// At first we specify the initial state. The LEDs are active low (see board.h).
	// So we have to set the pins to switch them off. LED1 and LED2 are switched off.
    LED_PORT.OUT = (LED1_PIN_bm|LED2_PIN_bm);
	// LEDs need power to light up. Therefore pin 0, 1, 2 and 3 must be output.
    LED_PORT.DIR = (LED0_PIN_bm|LED1_PIN_bm|LED2_PIN_bm|LED3_PIN_bm);
	/***** Use Hardware *****/
	// The super loop is the section where the hardware is used and controlled.
	// We want that LED1 and LED2 are blinking.
    while(1)
    {
		// Switch LED1 and LED 2 on. The LEDs are active low. So we clear the pins.
		// Please see module 4.3.1 for the details on bit manipulation.
        LED_PORT.OUT &= ~(LED1_PIN_bm|LED2_PIN_bm);
		// Let's wait a bit.
	    _delay_ms(500);
		// Switch LED1 and LED 2 off again.
        LED_PORT.OUT |= (LED1_PIN_bm|LED2_PIN_bm);
		// Let's wait again a bit.
	    _delay_ms(500);
    }
}

