/** \file main.c
 *
 * \brief GPIO: push-buttons.
 *
 * This example program checks if push-buttons are pressed.
 *
 * The relevant registers are:
 * - DIR: Data Direction Register
 * - IN: Data Input Value Register
 * - PINnCTRL: Pin n Configuration Register
 *
 * Please see modules 4.2.1 and 4.3.3 for more information.
 *
 * \author    Wolfgang Neff
 * \version   1.4
 * \date      2018-06-27
 *
 * \par History
 *      Created: 2013-07-16 \n
 *      Modified: 2014-09-28 \n
 *      Modified: 2014-10-12 \n
 *      Modified: 2015-01-27 \n
 *      Modified: 2018-06-27
 */

#include <avr/io.h>
#include "board.h"

// We want to switch LED0 on if button 0 is pressed and
// we want to switch it off if button 1 is pressed.
int main(void)
{
	/***** Initialize the LED. *****/
    LED_PORT.DIR = LED0_PIN_bm;
	/***** Initialize the push-buttons. *****/
	// Push-buttons require pull resistors. Our push-buttons are active low.
	// So we activate the pull up resistors.
	BUTTON0_PINCTRL = PORT_OPC_PULLUP_gc;
	BUTTON1_PINCTRL = PORT_OPC_PULLUP_gc;
	/***** Super loop *****/
	// This is the control section.
	while(1)
	{
		// We check if button 0 is pressed. The buttons are active low.
		// Please see module 4.3.1 for the details on bit manipulation.
        if (!(BUTTON_LOW_PORT.IN & BUTTON0_PIN_bm)) {
			// Switch LED on.
			LED_PORT.OUT &= ~LED0_PIN_bm;
		}
		// We check if button 1 is pressed.
        if (!(BUTTON_LOW_PORT.IN & BUTTON1_PIN_bm)) {
			// Switch LED off.
			LED_PORT.OUT |= LED0_PIN_bm;
		}
	}
}
