/** \file console.h
 *
 * \brief Connect stdio with the USB-USART gateway.
 *
 * This module connects stdio with the USB-USART gateway (USARTC0) so that
 * the standard input/output functions such as getchar, putchar, gets,
 * puts, printf and scanf can be used with a terminal such as PuTTY.
 *
 * \author    Wolfgang Neff
 * \version   1.3
 * \date      2017-12-10
 *
 * \par History
 *      Created: 2013-07-20 \n
 *      Modified: 2014-10-17 \n
 *      Modified: 2017-11-26 \n
 *      Modified: 2017-12-10
 *
 * \note Serial line parameters: 115200 8N1
 */

#ifndef CONSOLE_H_
#define CONSOLE_H_

#include <stdio.h>

#ifdef __cplusplus
extern "C"
{
#endif

/// <summary>Initialize console.</summary>
/// <remarks>
/// This routine initializes the USB-USART gateway (USARTC0) and connects
/// it with stdio.
/// </remarks>
void console_init(void);

/// <summary>Clear screen.</summary>
/// <remarks>
/// This routine erases the screen with the background color and moves
/// the cursor to its home position. This routine requires an ANSI/VT100
/// compatible terminal.
/// </remarks>
void console_clear(void);

#ifdef __cplusplus
}
#endif

#endif /* CONSOLE_H_ */
