/*
 * console.c
 *
 * Version: 1.3
 * Created: 2013-07-20
 * Modified: 2014-10-17
 * Modified: 2017-11-26
 * Modified: 2017-12-10
 *  Author: Wolfgang Neff
 */ 

#include <stdlib.h>
#include <avr/io.h>

#include "board.h"
#include "console.h"

static FILE console_in = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_READ);
static FILE console_out = FDEV_SETUP_STREAM(NULL, NULL, _FDEV_SETUP_WRITE);

static int usart_getc(FILE *stream)
{
	while (!(USB_USART_MODULE.STATUS & USART_RXCIF_bm));
	char data = USB_USART_MODULE.DATA;
	return (data=='\r') ? '\n' : data;
}

static int usart_putc(char c, FILE *stream)
{
	if (c == '\n') usart_putc('\r', stream);
	while (!(USB_USART_MODULE.STATUS & USART_DREIF_bm));
	USB_USART_MODULE.DATA = c;
	return EXIT_SUCCESS;
}

void console_init(void)
{
	USB_USART_PORT.OUT |= USB_USART_TX_PIN_bm;
	USB_USART_PORT.DIR |= USB_USART_TX_PIN_bm;
	USB_USART_PORT.DIR &= ~USB_USART_RX_PIN_bm;
	USB_USART_MODULE.BAUDCTRLA = USB_USART_BSEL & USART_BSEL_gm;
	USB_USART_MODULE.BAUDCTRLB = (USB_USART_BSCALE<<USART_BSCALE_gp) | ((USB_USART_BSEL>>8) & ~USART_BSCALE_gp);
	USB_USART_MODULE.CTRLC = USB_USART_CONFIG;
	USB_USART_MODULE.CTRLB |= (USART_RXEN_bm | USART_TXEN_bm);
	console_in.get = usart_getc;
	console_out.put = usart_putc;
   	stdin  = &console_in;
    stderr = &console_out;
    stdout = &console_out;
}

void console_clear(void)
{
	putchar('\x1B');
	putchar('[');
	putchar('2');
	putchar('J');
	putchar('\x1B');
	putchar('[');
	putchar('H');
}
